@@ -1,7 +1,5 @@
 package Net::Amazon::S3;
-{
-  $Net::Amazon::S3::VERSION = '0.60';
-}
+$Net::Amazon::S3::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 
@@ -17,6 +15,7 @@ use Net::Amazon::S3::Client::Bucket;
 use Net::Amazon::S3::Client::Object;
 use Net::Amazon::S3::HTTPRequest;
 use Net::Amazon::S3::Request;
+use Net::Amazon::S3::Request::AbortMultipartUpload;
 use Net::Amazon::S3::Request::CompleteMultipartUpload;
 use Net::Amazon::S3::Request::CreateBucket;
 use Net::Amazon::S3::Request::DeleteBucket;
@@ -39,17 +38,19 @@ use URI::Escape qw(uri_escape_utf8);
 use XML::LibXML;
 use XML::LibXML::XPathContext;
 
-has 'aws_access_key_id'     => ( is => 'ro', isa => 'Str', required => 1 );
-has 'aws_secret_access_key' => ( is => 'ro', isa => 'Str', required => 1 );
+has 'use_iam_role' => ( is => 'ro', isa => 'Bool', required => 0, default => 0);
+has 'aws_access_key_id'     => ( is => 'rw', isa => 'Str', required => 0 );
+has 'aws_secret_access_key' => ( is => 'rw', isa => 'Str', required => 0 );
 has 'secure' => ( is => 'ro', isa => 'Bool', required => 0, default => 0 );
 has 'timeout' => ( is => 'ro', isa => 'Num',  required => 0, default => 30 );
 has 'retry'   => ( is => 'ro', isa => 'Bool', required => 0, default => 0 );
+has 'host'    => ( is => 'ro', isa => 'Str',  required => 0, default => 's3.amazonaws.com' );
 
 has 'libxml' => ( is => 'rw', isa => 'XML::LibXML',    required => 0 );
 has 'ua'     => ( is => 'rw', isa => 'LWP::UserAgent', required => 0 );
 has 'err'    => ( is => 'rw', isa => 'Maybe[Str]',     required => 0 );
 has 'errstr' => ( is => 'rw', isa => 'Maybe[Str]',     required => 0 );
-has 'aws_session_token' => ( is => 'ro', isa => 'Str', required => 0 );
+has 'aws_session_token' => ( is => 'rw', isa => 'Str', required => 0 );
 
 __PACKAGE__->meta->make_immutable;
 
@@ -59,6 +60,13 @@ my $KEEP_ALIVE_CACHESIZE = 10;
 sub BUILD {
     my $self = shift;
 
+    if (!$self->use_iam_role) {
+        if (!defined($self->aws_secret_access_key) || !defined($self->aws_access_key_id)) {
+            die("Must specify aws_secret_access_key and aws_access_key_id");
+        }
+    }
+
+
     my $ua;
     if ( $self->retry ) {
         $ua = LWP::UserAgent::Determined->new(
@@ -346,46 +354,6 @@ sub _send_request_expect_nothing {
     return 0;
 }
 
-# Send a HEAD request first, to find out if we'll be hit with a 307 redirect.
-# Since currently LWP does not have true support for 100 Continue, it simply
-# slams the PUT body into the socket without waiting for any possible redirect.
-# Thus when we're reading from a filehandle, when LWP goes to reissue the request
-# having followed the redirect, the filehandle's already been closed from the
-# first time we used it. Thus, we need to probe first to find out what's going on,
-# before we start sending any actual data.
-sub _send_request_expect_nothing_probed {
-    my ( $self, $http_request ) = @_;
-
-    my $head = Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self,
-        method => 'HEAD',
-        path   => $http_request->uri->path,
-    )->http_request;
-
-    #my $head_request = $self->_make_request( $head );
-    my $override_uri = undef;
-
-    my $old_redirectable = $self->ua->requests_redirectable;
-    $self->ua->requests_redirectable( [] );
-
-    my $response = $self->_do_http($head);
-
-    if ( $response->code =~ /^3/ && defined $response->header('Location') ) {
-        $override_uri = $response->header('Location');
-    }
-
-    $http_request->uri($override_uri) if defined $override_uri;
-
-    $response = $self->_do_http($http_request);
-    $self->ua->requests_redirectable($old_redirectable);
-
-    return 1 if $response->code =~ /^2\d\d$/;
-
-    # anything else is a failure, and we save the parsed result
-    $self->_remember_errors( $response->content );
-    return 0;
-}
-
 sub _croak_if_response_error {
     my ( $self, $response ) = @_;
     unless ( $response->code =~ /^2\d\d$/ ) {
@@ -440,13 +408,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3 - Use the Amazon S3 - Simple Storage Service
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -457,6 +427,9 @@ version 0.60
   my $s3 = Net::Amazon::S3->new(
       {   aws_access_key_id     => $aws_access_key_id,
           aws_secret_access_key => $aws_secret_access_key,
+          # or use an IAM role.
+          use_iam_role          => 1
+
           retry                 => 1,
       }
   );
@@ -576,6 +549,11 @@ If you are using temporary credentials provided by the AWS Security Token
 Service, set the token here, and it will be added to the request in order to
 authenticate it.
 
+=item use_iam_role
+
+If you'd like to use IAM provided temporary credentials, pass this option
+with a true value.
+
 =item secure
 
 Set this to C<1> if you want to use SSL-encrypted connections when talking
@@ -592,6 +570,11 @@ If this library should retry upon errors. This option is recommended.
 This uses exponential backoff with retries after 1, 2, 4, 8, 16, 32 seconds,
 as recommended by Amazon. Defaults to off.
 
+=item host
+
+The S3 host endpoint to use. Defaults to 's3.amazonaws.com'. This allows
+you to connect to any S3-compatible host.
+
 =back
 
 =head2 buckets
@@ -852,11 +835,11 @@ L<Net::Amazon::S3::Bucket>
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
