@@ -1,7 +1,5 @@
 package Net::Amazon::S3::Client::Bucket;
-{
-  $Net::Amazon::S3::Client::Bucket::VERSION = '0.60';
-}
+$Net::Amazon::S3::Client::Bucket::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Data::Stream::Bulk::Callback;
@@ -71,6 +69,8 @@ sub location_constraint {
     return $lc;
 }
 
+sub object_class { 'Net::Amazon::S3::Client::Object' }
+
 sub list {
     my ( $self, $conf ) = @_;
     $conf ||= {};
@@ -107,7 +107,7 @@ sub list {
  #                $xpc->findvalue( ".//s3:DisplayName", $node ),
 
                 push @objects,
-                    Net::Amazon::S3::Client::Object->new(
+                    $self->object_class->new(
                     client => $self->client,
                     bucket => $self,
                     key    => $xpc->findvalue( './s3:Key', $node ),
@@ -139,17 +139,36 @@ sub delete_multi_object {
     my $self = shift;
     my @objects = @_;
     return unless( scalar(@objects) );
-    my $http_request = Net::Amazon::S3::Request::DeleteMultiObject->new(
-        s3      => $self->client->s3,
-        bucket  => $self->name,
-        keys    => [ map($_->key, @objects) ],
-    )->http_request;
-    return $self->client->_send_request($http_request);
+
+    # Since delete can handle up to 1000 requests, be a little bit nicer
+    # and slice up requests and also allow keys to be strings
+    # rather than only objects.
+    my $last_result;
+    while (scalar(@objects) > 0) {
+        my $http_request = Net::Amazon::S3::Request::DeleteMultiObject->new(
+            s3      => $self->client->s3,
+            bucket  => $self->name,
+            keys    => [map {
+                if (ref($_)) {
+                    $_->key
+                } else {
+                    $_
+                }
+            } splice @objects, 0, ((scalar(@objects) > 1000) ? 1000 : scalar(@objects))]
+        )->http_request;
+
+        $last_result = $self->client->_send_request($http_request);
+
+        if (!$last_result->is_success()) {
+            last;
+        }
+    }
+    return $last_result;
 }
 
 sub object {
     my ( $self, %conf ) = @_;
-    return Net::Amazon::S3::Client::Object->new(
+    return $self->object_class->new(
         client => $self->client,
         bucket => $self,
         %conf,
@@ -163,13 +182,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Client::Bucket - An easy-to-use Amazon S3 client bucket
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -256,17 +277,22 @@ This module represents buckets.
 =head2 delete_multi_object
 
   # delete multiple objects using a multi object delete operation
-  # Accepts a list of L<Net::Amazon::S3::Client::Object> objects.
-  # Limited to a maximum of 1000 objects in one operation
+  # Accepts a list of L<Net::Amazon::S3::Client::Object or String> objects.
   $bucket->delete_multi_object($object1, $object2)
 
+=head2 object_class
+
+  # returns string "Net::Amazon::S3::Client::Object"
+  # allowing subclasses to add behavior.
+  my $object_class = $bucket->object_class;
+
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
