@@ -1,11 +1,9 @@
 package Net::Amazon::S3::Client::Object;
-{
-  $Net::Amazon::S3::Client::Object::VERSION = '0.60';
-}
+$Net::Amazon::S3::Client::Object::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use DateTime::Format::HTTP;
-use Digest::MD5 qw(md5_hex);
+use Digest::MD5 qw(md5 md5_hex);
 use Digest::MD5::File qw(file_md5 file_md5_hex);
 use File::stat;
 use MIME::Base64;
@@ -19,7 +17,7 @@ enum 'AclShort' =>
     [ qw(private public-read public-read-write authenticated-read) ];
 
 enum 'StorageClass' =>
-    qw(standard reduced_redundancy);
+    [ qw(standard reduced_redundancy) ];
 
 has 'client' =>
     ( is => 'ro', isa => 'Net::Amazon::S3::Client', required => 1 );
@@ -49,6 +47,11 @@ has 'content_encoding' => (
     isa      => 'Str',
     required => 0,
 );
+has 'cache_control' => (
+    is       => 'ro',
+    isa      => 'Str',
+    required => 0,
+);
 has 'storage_class' => (
     is       => 'ro',
     isa      => 'StorageClass',
@@ -61,6 +64,11 @@ has 'user_metadata' => (
     required => 0,
     default  => sub { {} },
 );
+has 'encryption' => (
+    is       => 'ro',
+    isa      => 'Maybe[Str]',
+    required => 0,
+);
 
 __PACKAGE__->meta->make_immutable;
 
@@ -95,14 +103,8 @@ sub _get {
     my $md5_hex = md5_hex($content);
     my $etag = $self->etag || $self->_etag($http_response);
     confess 'Corrupted download'
-      if( !$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
+        if( !$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
 
-    if ( $self->etag ) {
-        confess 'Corrupted download' if $self->etag ne $md5_hex;
-    } else {
-        confess 'Corrupted download'
-            if $self->_etag($http_response) ne $md5_hex;
-    }
     return $http_response;
 }
 
@@ -116,8 +118,8 @@ sub get_decoded {
     return $self->_get->decoded_content(@_);
 }
 
-sub get_filename {
-    my ($self, $filename) = @_;
+sub get_callback {
+    my ( $self, $callback ) = @_;
 
     my $http_request = Net::Amazon::S3::Request::GetObject->new(
         s3     => $self->client->s3,
@@ -127,15 +129,30 @@ sub get_filename {
     )->http_request;
 
     my $http_response
-        = $self->client->_send_request($http_request, $filename);
+        = $self->client->_send_request( $http_request, $callback );
+
+    return $http_response;
+}
+
+sub get_filename {
+    my ( $self, $filename ) = @_;
+
+    my $http_request = Net::Amazon::S3::Request::GetObject->new(
+        s3     => $self->client->s3,
+        bucket => $self->bucket->name,
+        key    => $self->key,
+        method => 'GET',
+    )->http_request;
+
+    my $http_response
+        = $self->client->_send_request( $http_request, $filename );
 
     $self->_load_user_metadata($http_response);
 
     my $md5_hex = file_md5_hex($filename);
-
     my $etag = $self->etag || $self->_etag($http_response);
-    confess
-      'Corrupted download' if(!$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
+    confess 'Corrupted download'
+        if( !$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
 }
 
 sub _load_user_metadata {
@@ -178,6 +195,9 @@ sub _put {
     if ( $self->content_disposition ) {
         $conf->{'Content-Disposition'} = $self->content_disposition;
     }
+    if ( $self->cache_control ) {
+        $conf->{'Cache-Control'} = $self->cache_control;
+    }
     if ( $self->storage_class && $self->storage_class ne 'standard' ) {
         $conf->{'x-amz-storage-class'} = uc $self->storage_class;
     }
@@ -185,12 +205,13 @@ sub _put {
         for keys %{ $self->user_metadata };
 
     my $http_request = Net::Amazon::S3::Request::PutObject->new(
-        s3        => $self->client->s3,
-        bucket    => $self->bucket->name,
-        key       => $self->key,
-        value     => $value,
-        headers   => $conf,
-        acl_short => $self->acl_short,
+        s3         => $self->client->s3,
+        bucket     => $self->bucket->name,
+        key        => $self->key,
+        value      => $value,
+        headers    => $conf,
+        acl_short  => $self->acl_short,
+        encryption => $self->encryption,
     )->http_request;
 
     my $http_response = $self->client->_send_request($http_request);
@@ -234,6 +255,7 @@ sub initiate_multipart_upload {
         s3     => $self->client->s3,
         bucket => $self->bucket->name,
         key    => $self->key,
+        encryption => $self->encryption,
     )->http_request;
     my $xpc = $self->client->_send_request_xpc($http_request);
     my $upload_id = $xpc->findvalue('//s3:UploadId');
@@ -258,6 +280,22 @@ sub complete_multipart_upload {
     return $self->client->_send_request($http_request);
 }
 
+sub abort_multipart_upload {
+    my $self = shift;
+
+    my %args = ref($_[0]) ? %{$_[0]} : @_;
+
+    #set default args
+    $args{s3}       = $self->client->s3;
+    $args{key}      = $self->key;
+    $args{bucket}   = $self->bucket->name;
+
+    my $http_request =
+      Net::Amazon::S3::Request::AbortMultipartUpload->new(%args)->http_request;
+    return $self->client->_send_request($http_request);
+}
+
+
 sub put_part {
     my $self = shift;
 
@@ -366,13 +404,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Client::Object - An easy-to-use Amazon S3 client object
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -413,6 +453,13 @@ version 0.60
   # return the URI of a publically-accessible object
   my $uri = $object->uri;
 
+  # to store a new object with server-side encryption enabled
+  my $object = $bucket->object(
+    key        => 'my secret',
+    encryption => 'AES256',
+  );
+  $object->put('this data will be stored using encryption.');
+
   # upload a file
   my $object = $bucket->object(
     key          => 'images/my_hat.jpg',
@@ -598,15 +645,15 @@ C<user_metadata>.
 To upload an object with user metadata, set C<user_metadata> at construction
 time to a hashref, with no C<x-amz-meta-> prefixes on the key names.  When
 downloading an object, the C<get>, C<get_decoded> and C<get_filename>
-methods set the contents of C<user_metadata> to the same format.
+ethods set the contents of C<user_metadata> to the same format.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
