@@ -1,7 +1,5 @@
 package Net::Amazon::S3::HTTPRequest;
-{
-  $Net::Amazon::S3::HTTPRequest::VERSION = '0.60';
-}
+$Net::Amazon::S3::HTTPRequest::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use HTTP::Date;
@@ -10,6 +8,7 @@ use Moose::Util::TypeConstraints;
 use URI::Escape qw( uri_escape_utf8 );
 use URI::QueryParam;
 use URI;
+use VM::EC2::Security::CredentialCache;
 
 # ABSTRACT: Create a signed HTTP::Request
 
@@ -24,7 +23,7 @@ has 'path'   => ( is => 'ro', isa => 'Str',             required => 1 );
 has 'headers' =>
     ( is => 'ro', isa => 'HashRef', required => 0, default => sub { {} } );
 has 'content' =>
-    ( is => 'ro', isa => 'Str|CodeRef', required => 0, default => '' );
+    ( is => 'ro', isa => 'Str|CodeRef|ScalarRef', required => 0, default => '' );
 has 'metadata' =>
     ( is => 'ro', isa => 'HashRef', required => 0, default => sub { {} } );
 
@@ -44,10 +43,8 @@ sub http_request {
     $self->_add_auth_header( $http_headers, $method, $path )
         unless exists $headers->{Authorization};
     my $protocol = $self->s3->secure ? 'https' : 'http';
-    my $uri = "$protocol://s3.amazonaws.com/$path";
-    if ( $path =~ m{^([^/?]+)(.*)} && _is_dns_bucket($1) ) {
-        $uri = "$protocol://$1.s3.amazonaws.com$2";
-    }
+    my $host = $self->s3->host;
+    my $uri = "$protocol://$host/$path";
 
     my $request
         = HTTP::Request->new( $method, $uri, $http_headers, $content );
@@ -74,10 +71,9 @@ sub query_string_authentication_uri {
         = $self->_encode( $aws_secret_access_key, $canonical_string );
 
     my $protocol = $self->s3->secure ? 'https' : 'http';
-    my $uri = "$protocol://s3.amazonaws.com/$path";
-    if ( $path =~ m{^([^/?]+)(.*)} && _is_dns_bucket($1) ) {
-        $uri = "$protocol://$1.s3.amazonaws.com$2";
-    }
+    my $host = $self->s3->host;
+    my $uri = "$protocol://$host/$path";
+
     $uri = URI->new($uri);
 
     $uri->query_param( AWSAccessKeyId => $aws_access_key_id );
@@ -89,6 +85,15 @@ sub query_string_authentication_uri {
 
 sub _add_auth_header {
     my ( $self, $headers, $method, $path ) = @_;
+
+    if ($self->s3->use_iam_role) {
+        my $creds = VM::EC2::Security::CredentialCache->get();
+        defined($creds) || die("Unable to retrieve IAM role credentials");
+        $self->s3->aws_access_key_id($creds->accessKeyId);
+        $self->s3->aws_secret_access_key($creds->secretAccessKey);
+        $self->s3->aws_session_token($creds->sessionToken);
+    }
+
     my $aws_access_key_id     = $self->s3->aws_access_key_id;
     my $aws_secret_access_key = $self->s3->aws_secret_access_key;
     my $aws_session_token     = $self->s3->aws_session_token;
@@ -182,26 +187,6 @@ sub _encode {
     }
 }
 
-# EU buckets must be accessed via their DNS name. This routine figures out if
-# a given bucket name can be safely used as a DNS name.
-sub _is_dns_bucket {
-    my $bucketname = $_[0];
-
-    if ( length $bucketname > 63 ) {
-        return 0;
-    }
-    if ( length $bucketname < 3 ) {
-        return;
-    }
-    return 0 unless $bucketname =~ m{^[a-z0-9][a-z0-9.-]+$};
-    my @components = split /\./, $bucketname;
-    for my $c (@components) {
-        return 0 if $c =~ m{^-};
-        return 0 if $c =~ m{-$};
-        return 0 if $c eq '';
-    }
-    return 1;
-}
 
 # generates an HTTP::Headers objects given one hash that represents http
 # headers to set and another hash that represents an object's metadata.
@@ -239,13 +224,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::HTTPRequest - Create a signed HTTP::Request
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -277,11 +264,11 @@ URI.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
