@@ -1,7 +1,5 @@
 package Net::Amazon::S3::Request;
-{
-  $Net::Amazon::S3::Request::VERSION = '0.60';
-}
+$Net::Amazon::S3::Request::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Moose::Util::TypeConstraints;
@@ -49,7 +47,7 @@ __PACKAGE__->meta->make_immutable;
 
 sub _uri {
     my ( $self, $key ) = @_;
-    return ($key)
+    return (defined($key))
         ? $self->bucket . "/" . (join '/', map {$self->s3->_urlencode($_)} split /\//, $key)
         : $self->bucket . "/";
 }
@@ -60,13 +58,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request - Base class for request objects
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,11 @@ classes.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
