@@ -1,9 +1,6 @@
 package Net::Amazon::S3::Request::DeleteMultiObject;
-{
-  $Net::Amazon::S3::Request::DeleteMultiObject::VERSION = '0.60';
-}
+$Net::Amazon::S3::Request::DeleteMultiObject::VERSION = '0.80';
 use Moose 0.85;
-
 use Digest::MD5 qw/md5 md5_hex/;
 use MIME::Base64;
 use Carp qw/croak/;
@@ -60,13 +57,15 @@ sub http_request {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request::DeleteMultiObject - An internal class to delete multiple objects from a bucket
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -90,11 +89,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
