@@ -1,17 +1,15 @@
 package Net::Amazon::S3::Request::InitiateMultipartUpload;
-{
-  $Net::Amazon::S3::Request::InitiateMultipartUpload::VERSION = '0.60';
-}
-
+$Net::Amazon::S3::Request::InitiateMultipartUpload::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
-has 'bucket'    => ( is => 'ro', isa => 'BucketName',      required => 1 );
-has 'key'       => ( is => 'ro', isa => 'Str',             required => 1 );
-has 'acl_short' => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
+has 'bucket'     => ( is => 'ro', isa => 'BucketName',      required => 1 );
+has 'key'        => ( is => 'ro', isa => 'Str',             required => 1 );
+has 'acl_short'  => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
 has 'headers' =>
     ( is => 'ro', isa => 'HashRef', required => 0, default => sub { {} } );
+has 'encryption' => ( is => 'ro', isa => 'Maybe[Str]',      required => 0 );
 
 __PACKAGE__->meta->make_immutable;
 
@@ -22,6 +20,9 @@ sub http_request {
     if ( $self->acl_short ) {
         $headers->{'x-amz-acl'} = $self->acl_short;
     }
+    if ( defined $self->encryption ) {
+        $headers->{'x-amz-server-side-encryption'} = $self->encryption;
+    }
 
     return Net::Amazon::S3::HTTPRequest->new(
         s3      => $self->s3,
@@ -35,13 +36,15 @@ sub http_request {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request::InitiateMultipartUpload - An internal class to begin a multipart upload
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -65,11 +68,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
