@@ -1,14 +1,12 @@
 package Net::Amazon::S3::Request::PutPart;
-{
-  $Net::Amazon::S3::Request::PutPart::VERSION = '0.60';
-}
+$Net::Amazon::S3::Request::PutPart::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
 has 'bucket'        => ( is => 'ro', isa => 'BucketName',      required => 1 );
 has 'key'           => ( is => 'ro', isa => 'Str',             required => 1 );
-has 'value'         => ( is => 'ro', isa => 'Str|CodeRef',     required => 0 );
+has 'value'         => ( is => 'ro', isa => 'Str|CodeRef|ScalarRef',     required => 0 );
 has 'upload_id'     => ( is => 'ro', isa => 'Str',             required => 1 );
 has 'part_number'   => ( is => 'ro', isa => 'Int',             required => 1 );
 has 'copy_source_bucket'    => ( is => 'ro', isa => 'Str',     required => 0 );
@@ -41,7 +39,7 @@ sub http_request {
                    '&uploadId=' .
                    $self->upload_id,
         headers => $headers,
-        content => $self->value // '',
+        content => scalar( defined( $self->value ) ? $self->value : '' ),
     )->http_request;
 }
 
@@ -49,13 +47,15 @@ sub http_request {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request::PutPart - An internal class to put part of a multipart upload
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -84,11 +84,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
