@@ -1,7 +1,5 @@
 package Net::Amazon::S3::Request::SetObjectAccessControl;
-{
-  $Net::Amazon::S3::Request::SetObjectAccessControl::VERSION = '0.60';
-}
+$Net::Amazon::S3::Request::SetObjectAccessControl::VERSION = '0.80';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
@@ -47,13 +45,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request::SetObjectAccessControl - An internal class to set an object's access control
 
 =head1 VERSION
 
-version 0.60
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Rusty Conover <rusty@luckydinosaur.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
